@@ -9,10 +9,8 @@
         * common tags (up to a maximum of 25) including weight (0...5)
     * getting a user's full bookmark collection including private bookmarks
       IF you know username AND password
-    * getting a user's most recent public bookmarks if you do not know the
-      password
-    * getting a user's full tagging vocabulary, i.e. tags and tag counts,
-      in case you do not know the password
+    * getting a user's most recent public bookmarks
+    * getting a user's full tagging vocabulary, i.e. tags and tag counts
     * HTTP proxy support
 
     The official del.icio.us API does not provide all the functionality mentioned
@@ -38,7 +36,7 @@
 
 """
 
-__version__ = "1.4.2"
+__version__ = "1.4.3"
 
 import base64
 import cgi
